pub enum AgentMemoryError {
Validation(ValidationError),
Config(ConfigError),
Store(StoreError),
Lock(LockError),
NotFound(NotFoundError),
Io {
source: Error,
},
Overflow {
context: &'static str,
},
Internal {
message: &'static str,
},
}Variants
Validation(ValidationError)
A caller supplied invalid input.
Config(ConfigError)
The on-disk configuration was invalid or incomplete.
Store(StoreError)
A storage operation failed.
Lock(LockError)
A lock operation failed.
NotFound(NotFoundError)
A requested item does not exist.
Io
An unexpected I/O error occurred outside a more specific storage context.
Overflow
A size or capacity calculation would overflow or exceed a defined limit.
Internal
An internal invariant was violated.
It is intended for situations where the crate detects
Implementations